@@ -1296,6 +1296,13 @@ static int set_context(void)
 	bearer_list = mm_modem_list_bearers_sync(modem->modem, NULL, NULL);
 	active_bearers = 0;
 	if(bearer_list != NULL) {
+		MMBearerIpConfig *modem_bearer_ip6_config;
+		const gchar **dns_ipv6;
+		gchar *dns_ipv6_csv;
+		MMBearerIpConfig *modem_bearer_ip4_config;
+		const gchar **dns_ipv4;
+		gchar *dns_ipv4_csv;
+
 		for(l = bearer_list; l != NULL; l = l->next) {
 			active_bearers = active_bearers + 1;
 			modem_bearer =(MMBearer *) l->data;
@@ -1324,6 +1331,17 @@ static int set_context(void)
 					modem->context_path = mm_bearer_dup_path(modem_bearer);
 					modem->context_active = TRUE;
 					mms_service_set_apn(modem->service, modem->mms_apn);
+
+					modem_bearer_ip4_config = mm_bearer_peek_ipv4_config(modem_bearer);
+					dns_ipv4 = mm_bearer_ip_config_get_dns(modem_bearer_ip4_config);
+					dns_ipv4_csv = g_strjoinv(",", (gchar **)dns_ipv4);
+					modem_bearer_ip6_config = mm_bearer_peek_ipv6_config(modem_bearer);
+					dns_ipv6 = mm_bearer_ip_config_get_dns(modem_bearer_ip6_config);
+					dns_ipv6_csv = g_strjoinv(",", (gchar **)dns_ipv6);
+					mms_service_set_resolvers(modem->service, dns_ipv4_csv, dns_ipv6_csv);
+					DBG("DNS from modemmanager IPv6: %s, IPv4: %s", dns_ipv6_csv, dns_ipv4_csv);
+					g_free(dns_ipv6_csv);
+					g_free(dns_ipv4_csv);
 				}
 			}
 		}
@@ -1342,7 +1360,7 @@ static int set_context(void)
 				DBG("The modem bearer is disconnected! Please enable modem data");
 				return MMSD_MM_MODEM_NO_BEARERS_ACTIVE;
 			}
-			 else if(active_bearers < max_bearers) {
+			else if(active_bearers < max_bearers) {
 				/*
 				 * TODO: Modem manager does not support this yet, but this is
 				 *	 where to add code when Modem manager supports multiple
@@ -1662,4 +1680,3 @@ static void modemmanager_exit(void)
 }
 
 MMS_PLUGIN_DEFINE(modemmanager, modemmanager_init, modemmanager_exit)
-
