@@ -26,9 +26,6 @@
 
 #include "log.h"
 
-int __mms_log_init(const char *debug);
-void __mms_log_cleanup(void);
-
 #include "plugin.h"
 
 int __mms_plugin_init(void);
