@@ -1990,9 +1990,9 @@ char *mms_message_create_smil(GVariant *attachments)
 	smil_body = g_string_new(NULL);
 
 	while ((single_attachment = g_variant_iter_next_value (&iter))) {
-		const char *content_id;
-		const char *mime_type;
-		const char *file_path;
+		g_autofree char *content_id = NULL;
+		g_autofree char *mime_type = NULL;
+		g_autofree char *file_path = NULL;
 
 		g_variant_get (single_attachment, "(sss)", &content_id, &mime_type, &file_path);
 
