@@ -81,7 +81,7 @@ static int create_dirs(const char *filename, const mode_t mode)
 }
 
 
-static const char *generate_uuid_objpath(void)
+static char *generate_uuid_objpath(void)
 {
 	char *uuid, *reformatted;
 
@@ -179,11 +179,11 @@ error_mkstemp_full:
 	return written;
 }
 
-const char *mms_store(const char *service_id, const unsigned char *pdu,
+char *mms_store(const char *service_id, const unsigned char *pdu,
 							unsigned int len)
 {
 	char *pathname;
-	const char *uuid;
+	char *uuid;
 
 	uuid = generate_uuid_objpath();
 	if (uuid == NULL)
@@ -206,10 +206,10 @@ const char *mms_store(const char *service_id, const unsigned char *pdu,
 	return uuid;
 }
 
-const char *mms_store_file(const char *service_id, const char *path)
+char *mms_store_file(const char *service_id, const char *path)
 {
 	char *pathname;
-	const char *uuid;
+	char *uuid;
 	int fd;
 	struct stat st;
 	unsigned char *pdu;
